SQLAlchemy-Utils
================


SQLAlchemy-Utils provides custom data types and various utility functions for SQLAlchemy.


.. toctree::
   :maxdepth: 2

   installation
   listeners
   data_types
   range_data_types
   aggregates
   observers
   internationalization
   generic_relationship
   database_helpers
   foreign_key_helpers
   orm_helpers
   utility_classes
   models
   view
   testing
   license
